@@ -22,8 +22,8 @@
 
 #include <KContacts/VCardConverter>
 
-#include "KaddressbookGrantlee/GrantleeContactFormatter"
-#include "KaddressbookGrantlee/GrantleeContactGroupFormatter"
+#include <KaddressbookGrantlee/GrantleeContactFormatter>
+#include <KaddressbookGrantlee/GrantleeContactGroupFormatter>
 
 #include <Akonadi/Contact/ContactGroupViewer>
 #include <Akonadi/Contact/ContactViewer>
