@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,8 +22,8 @@
 #include <QStringList>
 
 namespace DefaultCompletion {
-QStringList defaultCompetion();
-QStringList defaultOptions();
+Q_REQUIRED_RESULT QStringList defaultCompetion();
+Q_REQUIRED_RESULT QStringList defaultOptions();
 }
 
 #endif // DEFAULTCOMPLETION_H
