@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -44,7 +44,7 @@ NewThemeDialog::NewThemeDialog(QWidget *parent)
     : QDialog(parent)
     , d(new GrantleeThemeEditor::NewThemeDialogPrivate)
 {
-    setWindowTitle(i18n("New Theme"));
+    setWindowTitle(i18nc("@title:window", "New Theme"));
 
     QWidget *w = new QWidget;
 
