@@ -57,8 +57,8 @@ QStringList DefaultCompletion::defaultCompetion()
         << QStringLiteral("header.datelocalelong")
         << QStringLiteral("header.useragent")
         << QStringLiteral("header.xmailer")
-        << QStringLiteral("header.resentfrom")
-        << QStringLiteral("header.resentfromi18n")
+        << QStringLiteral("header.resentFrom")
+        << QStringLiteral("header.resentFromi18n")
         << QStringLiteral("header.organization")
         << QStringLiteral("header.vcardname")
         << QStringLiteral("header.activecolordark")
@@ -71,8 +71,8 @@ QStringList DefaultCompletion::defaultCompetion()
         << QStringLiteral("header.photourl")
         << QStringLiteral("header.isprinting")
         << QStringLiteral("header.vcardi18n")
-        << QStringLiteral("header.resentto")
-        << QStringLiteral("header.resenttoi18n")
+        << QStringLiteral("header.resentTo")
+        << QStringLiteral("header.resentToi18n")
         << QStringLiteral("header.trashaction")
         << QStringLiteral("header.replyaction")
         << QStringLiteral("header.replyallaction")
