@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -22,7 +22,7 @@
 
 #include <QApplication>
 #include <QCommandLineParser>
-#include <kaboutdata.h>
+#include <KAboutData>
 #include <KLocalizedString>
 #include <Kdelibs4ConfigMigrator>
 #include <KCrash>
@@ -45,7 +45,7 @@ int main(int argc, char **argv)
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
                          i18n("Messageviewer Header Theme Editor"),
                          KAboutLicense::GPL_V2,
-                         i18n("Copyright © 2013-2019 headerthemeeditor authors"));
+                         i18n("Copyright © 2013-2020 headerthemeeditor authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
